@@ -22,7 +22,7 @@ setMethod("junctions", "GAlignments",
         ans <- make_GRangesList_from_CompressedIRangesList(rgl,
                                 seqnames(x), strand(x), seqinfo(x))
         if (use.mcols)
-            mcols(ans) <- mcols(x)
+            mcols(ans) <- mcols(x, use.names=FALSE)
         ans
     }
 )
@@ -39,7 +39,7 @@ setMethod("junctions", "GAlignmentPairs",
         ## 'mendoapply(c, first_junctions, last_junctions)'.
         ans <- pc(first_junctions, last_junctions)
         if (use.mcols) {
-            mcols(ans) <- mcols(x)
+            mcols(ans) <- mcols(x, use.names=FALSE)
         } else {
             mcols(ans) <- NULL
         }
@@ -61,7 +61,7 @@ setMethod("junctions", "GAlignmentsList",
         ans_partitioning <- PartitioningByEnd(ans_breakpoints, names=names(x))
         ans <- relist(grl@unlistData, ans_partitioning)
         if (use.mcols)
-            mcols(ans) <- mcols(x)
+            mcols(ans) <- mcols(x, use.names=FALSE)
         ans
     }
 )
@@ -192,10 +192,10 @@ summarizeJunctions <- function(x, with.revmap=FALSE, genome=NULL)
 {
     if (!is(x, "GRanges"))
         stop("'x' must be a GRanges object")
-    if (!identical(mcols(x)$thick, ranges(x)))
+    if (!identical(mcols(x, use.names=FALSE)$thick, ranges(x)))
         stop("this BED file doesn't look like the junctions.bed file ",
              "generated by TopHat")
-    blocks <- mcols(x)$blocks
+    blocks <- mcols(x, use.names=FALSE)$blocks
     stopifnot(all(elementNROWS(blocks) == 2L))
     unlisted_blocks <- unlist(blocks, use.names=FALSE)
     even_idx <- 2L * seq_along(x)
@@ -203,8 +203,8 @@ summarizeJunctions <- function(x, with.revmap=FALSE, genome=NULL)
     ans_start <- start(x) + end(unlisted_blocks)[odd_idx]
     ans_end <- start(x) + start(unlisted_blocks)[even_idx] - 2L
     ans <- GRanges(seqnames(x), IRanges(ans_start, ans_end), strand=strand(x))
-    mcols(ans) <- DataFrame(name=mcols(x)$name,
-                            score=as.integer(mcols(x)$score))
+    mcols(ans) <- DataFrame(name=mcols(x, use.names=FALSE)$name,
+                            score=as.integer(mcols(x, use.names=FALSE)$score))
     ans
 }
 
